@@ -19,19 +19,22 @@ _p2smap = {
     'datetime64[ns, UTC]': 'timestamp',
 }
 
-def pandas_type_to_sql(pt):
-    st = _p2smap.get(pt)
+def pandas_type_to_sql(pt, typemap={}):
+    if not isinstance(typemap, dict):
+        raise ValueError("typemap must be a dict")
+    # user defined typemap overrides _p2smap
+    st = typemap.get(pt, _p2smap.get(pt))
     if st is not None:
         return st
     raise ValueError("unexpected pandas column type '{pt}'".format(pt=pt))
 
 # add ability to specify optional dict for specific fields?
 # if column name is present, use specified value?
-def create_table_schema_pairs(df):
+def create_table_schema_pairs(df, typemap={}):
     if not isinstance(df, pd.DataFrame):
         raise ValueError("df must be a pandas DataFrame")
     ptypes = [str(e) for e in df.dtypes.to_list()]
-    stypes = [pandas_type_to_sql(e) for e in ptypes]
+    stypes = [pandas_type_to_sql(e, typemap=typemap) for e in ptypes]
     pz = list(zip(df.columns.to_list(), stypes))
     return ",\n".join(["    {n} {t}".format(n=e[0],t=e[1]) for e in pz])
 
